@@ -128,7 +128,7 @@
 {%- endmacro %}
 
 
-{# On Trino, 'cascade' isn't supported so we have to manually cascade. #}
+{# On Trino, 'cascade' is not supported so we have to manually cascade. #}
 {% macro trino__drop_schema(relation) -%}
   {% for row in list_relations_without_caching(relation) %}
     {% set rel_db = row[0] %}
@@ -151,11 +151,6 @@
 {% endmacro %}
 
 
-{% macro trino__load_csv_rows(model, agate_table) %}
-  {{ return(basic_load_csv_rows(model, 1000, agate_table)) }}
-{% endmacro %}
-
-
 {% macro trino__list_schemas(database) -%}
   {% call statement('list_schemas', fetch_result=True, auto_begin=False) %}
     select distinct schema_name
